/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_REPEAT_PLUGIN_H_
#define _GB2_REPEAT_PLUGIN_H_

#include <core_api/PluginModel.h>
#include <core_api/ObjectViewModel.h>

namespace GB2 {

class RepeatFinderPlugin : public Plugin {
	Q_OBJECT
public:
    RepeatFinderPlugin();
	
private:
    GObjectViewWindowContext* viewCtx;
};

class RepeatViewContext: public GObjectViewWindowContext {
    Q_OBJECT
public:
    RepeatViewContext(QObject* p);

protected slots:
    void sl_showDialog();
	void sl_showTandemDialog();

protected:
    virtual void initViewContext(GObjectView* view);
};


} //namespace

#endif
